#lang racket

(require vigracket)


;; Main program
;; -----------------------------------------------------------------------------
(define image_dir (current-directory))

(define resized_img (load-image (build-path image_dir "IMG_0705small.JPG")))
(define work_img (image->blue resized_img))



;;Parameters dep. on image size!
(define field_width 133)
(define field_height 133)


;;Feld 1: Oben rechts, gelbe Figur
;(define field_pos '(165 . 361))

;;Feld 2: Kronleuchter (Leer)
(define field_pos '(299 . 498))

(define (image->roi img pos)
  (subimage img
            (car pos)
            (cdr pos)
            (+ (car pos) field_width)
            (+ (cdr pos) field_height)))

(define ier (compose inexact->exact round))

;;Sections:
#|
     -- |  1  | --
     --------------
      2 |  3  | 4
     --------------
     -- |  5  | --
|#
(define (roi->section img section_id)
  (let ([section_width  (ier (/ field_width 3))]
        [section_height (ier (/ field_height 3))])
    (case section_id
      [(1)
       (subimage img section_width 0 (* 2 section_width) section_height)]
      [(2 3 4)
       (let ([xpos (* (- section_id 2) section_width)])
         (subimage img xpos section_height (+ xpos section_width) (* 2 section_height)))]
      [(5)
       (subimage img section_width (* 2 section_height) (* 2 section_width) (* 3 section_height))])))

(define section_ids '(1 2 3 4 5))
(define section_names '("oben" "links" "zentrum" "rechts" "unten"))

(define roi (image->roi work_img field_pos))

(define roi-sections (map (curry roi->section roi) section_ids))

(map image->bitmap roi-sections)

(define (histogram-1band img)
  (let* ([hist (make-vector 256)]
         [cx (/ (image-width  img) 2)]
         [cy (/ (image-height img) 2)])
    (image-for-each-index
     (lambda (x y band_id)
       (let ([val (ier (image-ref img x y band_id))])
         (vector-set! hist val (+ (vector-ref hist val) 1))))
     img)
    hist))

(define roi-sections-hist (map histogram-1band roi-sections))

(require plot)

(define (plot-hist hist [name ""])
  (plot (function (λ (x) (vector-ref hist (ier x))) 0 255 #:label name)))

(map plot-hist  roi-sections-hist section_names)