#lang racket

(require vigracket)


;; Main program
;; -----------------------------------------------------------------------------
(define image_dir (current-directory))

(define resized_img (load-image (build-path image_dir "IMG_0687small.JPG")))
(define work_img (image->red resized_img))



;;Parameters dep. on image size!
(define field_radius 25)

;;Only for the inner curcle
;(define field_radius 10)

;;Feld 1: Leer
(define field1_pos '(387 . 716))

;;Feld 2: Loch
(define field2_pos '(336 . 780))

;;Feld 3: dunkle Figur (kein Loch)
(define field3_pos '(315 . 860))

(define (image->roi img pos)
  (subimage img
            (- (car pos) field_radius)
            (- (cdr pos) field_radius)
            (+ (car pos) field_radius 1)
            (+ (cdr pos) field_radius 1)))

(define empty_roi (image->roi work_img field1_pos))
(define hole_roi  (image->roi work_img field2_pos))
(define fig_roi   (image->roi work_img field3_pos))

(show-image empty_roi "Leer")
(show-image hole_roi  "Loch")
(show-image fig_roi   "kein Loch")

(define ier (compose inexact->exact round))

(define (dist2 x1 y1 x2 y2)
  (+ (sqr (- x1 x2)) (sqr (- y1 y2))))

(define (circular-histogram-1band img)
  (let* ([hist (make-vector 256)]
         [cx (/ (image-width  img) 2)]
         [cy (/ (image-height img) 2)]
         [r2 (sqr field_radius)])
    (image-for-each-index
     (lambda (x y band_id)
       (when (<= (dist2 x y cx cy) r2) ;;If inside circle: Add to histogram
           (let ([val (ier (image-ref img x y band_id))])
             (vector-set! hist val (+ (vector-ref hist val) 1)))))
     img)
    hist))

(define empty_hist (circular-histogram-1band empty_roi))
(define hole_hist  (circular-histogram-1band hole_roi))
(define fig_hist   (circular-histogram-1band fig_roi))

(require plot)
(plot (function (λ (x) (vector-ref empty_hist (inexact->exact (round  x)))) 0 255 #:label "Empty hist"))
(plot (function (λ (x) (vector-ref hole_hist (inexact->exact (round  x)))) 0 255 #:label "Hole hist" #:color 2))
(plot (function (λ (x) (vector-ref fig_hist (inexact->exact (round  x)))) 0 255 #:label "Dark figure hist" #:color 3))